#
# spec file for package sphinxbase
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sphinxbase
Version:        0.8
Release:        7.2
Summary:        Support library required by Pocketsphinx
License:        BSD-2-Clause AND MIT
Group:          Productivity/Office/Other
URL:            http://cmusphinx.sourceforge.net/wiki/download/
Source:         http://downloads.sourceforge.net/project/cmusphinx/%{name}/%{version}/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM remove __DATE and __TIME
Patch0:         sphinxbase-no-date.patch
# PATCH-FIX-UPSTREAM fix doxygen documentation
Patch1:         sphinxbase-doxygen.patch
# PATCH-FIX-UPSTREAM fix largefile support
Patch2:         sphinxbase-largefile.patch
# PATCH-FIX-UPSTREAM initialize a variable
Patch3:         sphinxbase-uninit.patch
# PATCH-FIX-UPSTREAM boo#1127564
Patch4:         workaround-gcc-issue-on-i586.patch
Patch5:         use-python3.patch
BuildRequires:  alsa-devel
BuildRequires:  bison
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  libsndfile-devel
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Cython
BuildRequires:  python3-devel
Requires(post): update-alternatives
Requires(postun):update-alternatives
%if 0%{?suse_version} <= 1210
BuildRequires:  liblapack3
%else
BuildRequires:  lapack-devel
%endif

%description
CMU Sphinx toolkit is a speech recognition tool and has a number of packages for
different tasks and applications.

%package -n libsphinxbase1
Summary:        Sphinxbase speech recognizer library
Group:          System/Libraries

%description -n libsphinxbase1
CMU Sphinx toolkit is a speech recognition tool and has a number of packages for
different tasks and applications.

%package -n libsphinxad0
Summary:        Sphinxbase speech recognizer library
Group:          System/Libraries

%description -n libsphinxad0
CMU Sphinx toolkit is a speech recognition tool and has a number of packages for
different tasks and applications.

%package devel
Summary:        Headers for support library required by Pocketsphinx
Group:          Development/Libraries/C and C++
Requires:       alsa-devel
Requires:       lapack-devel
Requires:       libsndfile-devel
Requires:       libsphinxad0 = %{version}-%{release}
Requires:       libsphinxbase1 = %{version}-%{release}
Conflicts:      sphinxbase5-devel

%description devel
devel files for %{name}-%{version}

CMU Sphinx toolkit is a speech recognition tool and has a number of packages for
different tasks and applications.

%package -n python3-sphinxbase
Summary:        Python3 bindings for sphinxbase
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Conflicts:      python3-pocketsphinx-python <= 0.1.3
Conflicts:      python3-sphinxbase5

%description -n python3-sphinxbase
Python3 bindings for %{name}-%{version}

CMU Sphinx toolkit is a speech recognition tool and has a number of packages for
different tasks and applications.

%prep
%setup -q
%patch -P 0 -p1
%patch -P 1
%patch -P 2
%patch -P 3
%ifarch i586
%patch -P 4 -p1
%endif
%patch -P 5 -p1
# It has to be regenerated by cython
rm python/sphinxbase.c
sed -ie "s,\#\!%{_bindir}/env perl,#!%{_bindir}/perl," src/sphinx_lmtools/sphinx_lm_sort

%build
%configure --disable-static --with-python=%{_bindir}/python3
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}

# Prepare for alternatives
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for binary in sphinx_cepview sphinx_fe sphinx_jsgf2fsg sphinx_lm_convert \
              sphinx_lm_eval sphinx_pitch ; do
    mv %{buildroot}%{_bindir}/$binary %{buildroot}%{_bindir}/$binary-%{version}
    ln -s %{_sysconfdir}/alternatives/$binary %{buildroot}%{_bindir}/$binary
done

%ifarch x86_64 i586
%check
%make_build check
%endif

%post
update-alternatives --install %{_bindir}/sphinx_pitch sphinx_pitch %{_bindir}/sphinx_pitch-%{version} 10 \
  --slave %{_bindir}/sphinx_cepview sphinx_cepview %{_bindir}/sphinx_cepview-%{version} \
  --slave %{_bindir}/sphinx_fe sphinx_fe %{_bindir}/sphinx_fe-%{version} \
  --slave %{_bindir}/sphinx_jsgf2fsg sphinx_jsgf2fsg %{_bindir}/sphinx_jsgf2fsg-%{version} \
  --slave %{_bindir}/sphinx_lm_convert sphinx_lm_convert %{_bindir}/sphinx_lm_convert-%{version} \
  --slave %{_bindir}/sphinx_lm_eval sphinx_lm_eval %{_bindir}/sphinx_lm_eval-%{version}

%postun
if [ ! -f %{_bindir}/sphinx_pitch ]; then
    update-alternatives --remove sphinx_pitch %{_bindir}/sphinx_pitch-%{version}
fi

%post   -n libsphinxad0 -p /sbin/ldconfig
%postun -n libsphinxad0 -p /sbin/ldconfig
%post   -n libsphinxbase1 -p /sbin/ldconfig
%postun -n libsphinxbase1 -p /sbin/ldconfig

%files
%doc AUTHORS ChangeLog README NEWS
%license COPYING
%ghost %{_sysconfdir}/alternatives/sphinx_cepview
%ghost %{_sysconfdir}/alternatives/sphinx_fe
%ghost %{_sysconfdir}/alternatives/sphinx_jsgf2fsg
%ghost %{_sysconfdir}/alternatives/sphinx_lm_convert
%ghost %{_sysconfdir}/alternatives/sphinx_lm_eval
%ghost %{_sysconfdir}/alternatives/sphinx_pitch
%{_bindir}/sphinx_cepview*
%{_bindir}/sphinx_fe*
%{_bindir}/sphinx_jsgf2fsg*
%{_bindir}/sphinx_lm_convert*
%{_bindir}/sphinx_lm_eval*
%{_bindir}/sphinx_pitch*
%{_bindir}/sphinx_cont_adseg
%{_bindir}/sphinx_cont_fileseg
%{_bindir}/sphinx_lm_sort

%files -n libsphinxad0
%{_libdir}/libsphinxad.so.*

%files -n libsphinxbase1
%{_libdir}/libsphinxbase.so.*

%files devel
%{_libdir}/libsphinxbase.so
%{_libdir}/libsphinxad.so
%{_libdir}/pkgconfig/sphinxbase.pc
%{_includedir}/sphinxbase/

%files -n python3-sphinxbase
%{python3_sitearch}/SphinxBase-0.8-py%{python3_version}.egg-info
%{python3_sitearch}/sphinxbase*.so

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Apr 26 2022 Jan Engelhardt <jengelh@inai.de>
- Resolve rpmlint report "libsphinxbase1.x86_64: E:
  shlib-policy-name-error SONAME: libsphinxad.so.0, expected
  package suffix: 0".
* Thu Mar 26 2020 Antonio Larrosa <alarrosa@suse.com>
- sphinxbase-devel now conflicts with sphinxbase5-devel
- python3-sphinxbase now conflicts with python3-sphinxbase5 and
  python3-pocketsphinx-python <= 0.1.3
- Fix some symbol-not-found errors in the python3 port. Updated patch:
  * use-python3.patch
* Wed Mar 25 2020 Antonio Larrosa <alarrosa@suse.com>
- spec file cleanup
* Wed Jan 15 2020 Antonio Larrosa <alarrosa@suse.com>
- Generate python3 bindings instead of python2.
- Add use-python3.patch
* Fri Mar  1 2019 Antonio Larrosa <alarrosa@suse.com>
- Add workaround-gcc-issue-on-i586.patch to circumvent
  boo#1127564 while it's fixed in gcc
* Wed Feb 27 2019 Antonio Larrosa <alarrosa@suse.com>
- Add %%check section to run tests
* Sat Feb 23 2019 alarrosa@suse.com
- Use alternatives for some binaries to make it possible to have the package
  coinstallable with sphinxbase5 5prealpha
* Mon Aug 20 2018 alarrosa@suse.com
- Implement shared library packaging guideline
- Fix RPM groups
- Fix perl shebang to not use env
* Sun Aug 12 2018 alarrosa@suse.com
- Use %%license for license file
* Tue Sep  5 2017 alarrosa@suse.com
- Add sphinxbase-doxygen.patch, sphinxbase-largefile.patch and
  sphinxbase-uninit.patch to fix several issues. Patches obtained
  from the fedora package.
- Fixed license in spec file. It's BSD-2-Clause + MIT
- Regenerate sphinxbase.c with cython instead of using the
  (old) released code.
- Run spec-cleaner
- Move the python bindings to a new python2-sphinxbase package
* Mon Sep  1 2014 hrvoje.senjan@gmail.com
- Fix devel package requires; devel package needs libsndfile-devel,
  alsa-devel and lapack-devel
* Mon Sep  1 2014 hrvoje.senjan@gmail.com
- Revert the license change from previous submit; there is no
  indication that upstream changed the license
* Sat Aug 30 2014 i@marguerite.su
- update version 0.8
  * Functions added to share with Sphinxtrain
  * Fixed build for MINGW
  * Better support for Python 3.x
  * Jack backend
  * New argument type STRING_LIST for Sphinxtrain
- added patch: sphinxbase-no-date.patch
  * remove __DATE and __TIME
* Sat Nov 10 2012 alinm.elena@gmail.com
- initial commit
